Alexandre Julliard : winmm/tests: Increase the timing tolerances some more.

Alexandre Julliard julliard at winehq.org
Tue Jan 20 08:27:54 CST 2009


Module: wine
Branch: master
Commit: 023df8518303f55bda27316e320e53e6357a72b0
URL:    http://source.winehq.org/git/wine.git/?a=commit;h=023df8518303f55bda27316e320e53e6357a72b0

Author: Alexandre Julliard <julliard at winehq.org>
Date:   Tue Jan 20 14:02:12 2009 +0100

winmm/tests: Increase the timing tolerances some more.

---

 dlls/winmm/tests/wave.c |    4 ++--
 1 files changed, 2 insertions(+), 2 deletions(-)

diff --git a/dlls/winmm/tests/wave.c b/dlls/winmm/tests/wave.c
index b2b3d7c..22ada89 100644
--- a/dlls/winmm/tests/wave.c
+++ b/dlls/winmm/tests/wave.c
@@ -789,13 +789,13 @@ static void wave_out_test_deviceOut(int device, double duration,
             }
         }
 
         /* Check the sound duration was between -10% and +25% of the expected value */
         end=GetTickCount();
         actual = (end - start) / 1000.0;
         if (winetest_debug > 1)
             trace("sound duration=%g ms\n",1000*actual);
         ok((actual > (0.9 * (duration+paused))) &&
-           (actual < (1.25 * (duration+paused))),
+           (actual < (1.35 * (duration+paused))),
            "The sound played for %g ms instead of %g ms\n",
            1000*actual,1000*(duration+paused));
         for (i = 0; i < headers; i++) {
@@ -789,13 +789,13 @@ static void wave_out_test_deviceOut(int device, double duration,
         }
 
-        /* Check the sound duration was between -10% and +25% of the expected value */
+        /* Check the sound duration was between -10% and +35% of the expected value */
         end=GetTickCount();
         actual = (end - start) / 1000.0;




More information about the wine-cvs mailing list